%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Microstructure Diffusion Toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

.. toctree::
    :maxdepth: 2

    readme_latex
    install
    mle_fitting
    mcmc_sampling
    adding_components
    maps_visualizer
    concepts
    configuration
    FAQ <faq>
    scientific_articles
    credits
